% Start acer_fit.m --------------------------------------------------------

run('acer');

eta_0=; % [kN], Load value from where the extrapolation function starts
b0=mean(dataset); %Initial value for optimized constant b
c0=2; %Initial value for optimized constant c
x0=[b0,c0];
k=1; %Order of ACER function used for fitting of the extrapolation function

i=1;
% Find from which element number in dataset a function shall be fitted:
while eta(i)<eta_0
    i=i+1;
end
i=i+1; %Start point in data set for extrapolation function

rho_opt=real(rho(:,k)); %Some imaginary parts due to numerical errors
for j=i:(length(rho_opt)-1)
    if rho_opt(j)<0 %Only positive wheight factors are included
        j=j-1; %End point in load vector for extrapolation function
        break
    end
end

% For the fitting purpose (spanning from i to j):
rho_opt=rho_opt(i:j); 
ACER_opt=ACER(i:j,k);
eta_opt=eta(i:j);
ln_acer=log(ACER_opt);

% Objective function:
F = @(x) sqrt(rho_opt).*(ln_acer - sum(rho_opt.*ln_acer)-((sum(rho_opt.*...
    ((eta_opt - x(1)).^x(2).*ln_acer)) - sum(rho_opt.*(eta_opt - x(1))...
    .^x(2))*sum(rho_opt.*ln_acer))/(sum(rho_opt.*((eta_opt-x(1)).^x(2).*...
    (eta_opt - x(1)).^x(2))) - (sum(rho_opt.*(eta_opt - x(1)).^x(2)))...
    ^2))*((eta_opt - x(1)).^x(2) - sum(rho_opt.*(eta_opt - x(1)).^x(2))));

%Optimization characteristics:
ObFun_log_LS_NLINFIT_LM = optimset('Display','off','Algorithm',...
    'levenberg-marquardt','MaxFunEvals', 10000, 'MaxIter', 10000,'TolX',...
    1e-12, 'TolFun', 1e-12);

%Optimization:
x = lsqnonlin(F, x0, [], [], ObFun_log_LS_NLINFIT_LM);
inp = (eta_opt - x(1)).^x(2);
A = (sum(rho_opt.*(inp.*ln_acer)) - sum(rho_opt.*inp)*sum(rho_opt.*...
    ln_acer))/(sum(rho_opt.*(inp.*inp)) - (sum(rho_opt.*inp))^2);
B = sum(rho_opt.*ln_acer) - A*sum(rho_opt.*inp);
sol(1:4) = [-A x(1) x(2) exp(B)];
a=-A; %Parameter used for extrapolation function
b=x(1); %Parameter used for extrapolation function
c=x(2); %Parameter used for extrapolation function
q=exp(B); %Parameter used for extrapolation function

% Upper band of CI, Same procedure as for the extrapolation function:
ln_CIplus=log(CIplus(i:j,k));
b0plus=mean(CIplus);
c0plus=2;
x0plus=[b,c];
Fplus = @(xplus) sqrt(rho_opt).*(ln_CIplus - sum(rho_opt.*ln_CIplus) - ...
((sum(rho_opt.*((eta_opt - xplus(1)).^xplus(2).*ln_CIplus)) - sum...
(rho_opt.*(eta_opt - xplus(1)).^xplus(2))*sum(rho_opt.*ln_CIplus))/(sum...
(rho_opt.*((eta_opt - xplus(1)).^xplus(2).*(eta_opt - xplus(1)).^...
xplus(2))) - (sum(rho_opt.*(eta_opt - xplus(1)).^xplus(2)))^2))*...
((eta_opt - xplus(1)).^xplus(2) - sum(rho_opt.*(eta_opt - xplus(1)).^...
xplus(2))));

ObFun_log_LS_NLINFIT_LM = optimset('Display','off',...
    'Algorithm', 'levenberg-marquardt', ...
    'MaxFunEvals', 10000, 'MaxIter', 10000,...
    'TolX', 1e-12, 'TolFun', 1e-12);

xplus = lsqnonlin(Fplus, x0plus, [], [], ObFun_log_LS_NLINFIT_LM);
inp = (eta_opt - xplus(1)).^xplus(2);
A = (sum(rho_opt.*(inp.*ln_CIplus)) - sum(rho_opt.*inp)*sum(rho_opt.*...
    ln_CIplus))/(sum(rho_opt.*(inp.*inp)) - (sum(rho_opt.*inp))^2);
B = sum(rho_opt.*ln_CIplus) - A*sum(rho_opt.*inp);
solplus(1:4) = [-A xplus(1) xplus(2) exp(B)];
a_plus=-A;
b_plus=xplus(1);
c_plus=xplus(2);
q_plus=exp(B);

% Lower band of CI, Same procedure as for the extrapolation function:
ln_CIminus=log(CIminus(i:j,k));
b0minus=mean(CIminus);
c0minus=2;
x0minus=[b,c];
Fminus = @(xminus) sqrt(rho_opt).*(ln_CIminus - sum(rho_opt.*ln_CIminus)...
    -((sum(rho_opt.*((eta_opt - xminus(1)).^xminus(2).*ln_CIminus))-sum...
    (rho_opt.*(eta_opt - xminus(1)).^xminus(2))*sum(rho_opt.*...
    ln_CIminus))/(sum(rho_opt.*((eta_opt - xminus(1)).^xminus(2).*...
    (eta_opt-xminus(1)).^xminus(2))) - (sum(rho_opt.*(eta_opt-xminus(1))...
    .^xminus(2)))^2))*((eta_opt - xminus(1)).^xminus(2) - sum(rho_opt.*...
    (eta_opt - xminus(1)).^xminus(2))));

ObFun_log_LS_NLINFIT_LM = optimset('Display','off',...
    'Algorithm', 'levenberg-marquardt', ...
    'MaxFunEvals', 10000, 'MaxIter', 10000,...
    'TolX', 1e-12, 'TolFun', 1e-12);

xminus = lsqnonlin(Fminus, x0minus, [], [], ObFun_log_LS_NLINFIT_LM);
inp = (eta_opt - xminus(1)).^xminus(2);
A = (sum(rho_opt.*(inp.*ln_CIminus)) - sum(rho_opt.*inp)*sum(rho_opt.*...
    ln_CIminus))/(sum(rho_opt.*(inp.*inp)) - (sum(rho_opt.*inp))^2);
B = sum(rho_opt.*ln_CIminus) - A*sum(rho_opt.*inp);
solminus(1:4) = [-A xminus(1) xminus(2) exp(B)];
a_minus=-A;
b_minus=xminus(1);
c_minus=xminus(2);
q_minus=exp(B);

% Calculate estimated most probable largest value:
N=length(dataset);%length(dataset);
n_hour=60*N/((stop-start)*0.5);%loads per hour
P=((N-1)/N)^N;%Probability of exceeding most probable largest
eta_max_hat=b+((-1/a)*log(-(log(P))/(N*q)))^(1/c);

% For plotting:
x=eta_0:max(eta)*1.1;
y=q.*exp(-a.*(x-b).^c); %Extrapolation function
yplus=q_plus.*exp(-a_plus.*(x-b_plus).^c_plus); %Upper bound for CI
yminus=q_minus.*exp(-a_minus.*(x-b_minus).^c_minus); %Lower bound for CI

figure1 = figure;
% Create axes
axes1 = axes('Parent',figure1);
hold(axes1,'on');
xlim(axes1,[25 , max(eta)*1.25]); %Limits z-axis
ylim(axes1,[min(ACER(1:(end-1),k))*0.1 , 1]);%yplus(1)]); %Limits y-axis
title('Extrapolation scheme')
xlabel({'$\eta$ [kN/m]'},'Interpreter','latex')
ylabel({'ACER($\eta$,k=1)'},'Interpreter','latex')

dataset=sort(dataset);

% Plotting:
% ACER function
acer=stairs(eta(1:end),ACER(1:end,k),'Parent',axes1,'color',[0 0 1]);
% Extraploation function:
fit=semilogy(x,y,'-k');
% Upper confidence band for extrapolation function:
CIfit=semilogy(x,yplus,':k'); 
%Lower confidence band for extrapolation function:
semilogy(x,yminus,':k');
%Confidence interval bands for ACER function:
CIacer=semilogy(dataset(1:j),CIminus(1:j,k),dataset(1:end-1),...
    CIplus(1:end-1,k),'LineStyle','--','Color',[0 0 1]);

box(axes1,'on');
% Set the remaining axes properties:
set(axes1,'YMinorTick','on','YScale','log');
legend([acer,fit,CIacer(1),CIfit],{'ACER function',...
    'Extrapolation function','95% CI band for ACER function',...
    '95% CI band for extrapolation function'});...
    annotation('textbox',[0.18 0.18 0.1 0.07],'String',...
    {['\eta_{0} = ',num2str(eta_0)]},'FontSize',12.6,'EdgeColor','k');

% End acer_fit.m ----------------------------------------------------------