% Start asymptotic.m ------------------------------------------------------

clear all
load('ILMdata')
run('separate');

% User inputs:
Dt=; %length of applied sub-interval [min]
start=; %in the file "data"/"time"
stop=; %in the file "data"/"time"
LX=; % define strain sensor

% Threshold:
threshold=25; %[kN] >= 25. 25 is default in the data set
if threshold>25
a=1;
LX_copy=LX;
clearvars LX
for i=1:length(LX_copy)
    if LX_copy(i,2)>threshold
        LX(a,:)=LX_copy(i,:);
        a=a+1;
    end
end
end

% Extract and create data set:
peak_int=[];
dataset=[];
start_time=time(start);
stop_time=time(stop);
a1=1; %Evaluated element in LX
a2=1; %Sub-interval nr
a3=1; %Element nr in sub-interval
while start_time>LX(a1,1) %Finds start point in LX
    a1=a1+1;
end

while LX(a1,1)<=stop_time
    int=floor((LX(a1,1)-start_time)/(Dt*60)); %
    if int>a2
        if a3>1
        dataset(a2)=max(peak_int(a2,:)); %Max in subinterval a2 stored
        a2=a2+1; %New sub-interval is created
        a3=1;
        end
    end
    peak_int(a2,a3)=LX(a1,2);
    a1=a1+1;
    a3=a3+1;
end

dataset(a2)=max(peak_int(a2,:)); %Data set applied in analysis
dataset=sort(dataset);
if exist('bootstr','var')==0 %True if script is not ran by bootstrapping.m
dataset=dataset-threshold; %Subtracted the threshold for fitting purposes
end


% Empirical CDF:
p_i=1:length(dataset);
p_i=p_i/(length(dataset)+1);

% Plot in Gumbel probability paper:
x=dataset;
y=-log(-log(p_i));
hold on
figure(1)
scatter(x,y,'x')
xlabel('$y_{max,1min}$','Interpreter','latex')
ylabel('Cumulative Probability')
title('Asymptotic approach, Gumbel distribution')
hold off

% Least square fit:
l=lsline; %plot the fitted line
set(l(1),'color',0.0*[1 1 1]) %Color of the fitted line
m_c = polyfit(get(l,'xdata'),get(l,'ydata'),1);
m=m_c(1); %slope of fitted line
c=m_c(2); %ordinate interception for fitted line

if exist('bootstr','var')==0 %True if script is not ran by bootstrapping.m
% Coefficient of Determination (R^2):
f=m*x+c; %Fitted line
y_bar=mean(y);
SSres=sum((y-f).^2);
SStot=sum((y-y_bar).^2);
R_squared=1-(SSres/SStot);
end

% Parameter estimation based on probability paper:
beta=1/m;
alpha=-beta*c;

% Parameter estimation by MLE:
% alphabeta=evfit(-dataset);
% alpha=-alphabeta(1);
% beta=alphabeta(2);

% Kolmogorov-Smirnov test:
X_cdf=0:1:max(dataset)*1.1; %For fitted distribution
Y_cdf=exp(-exp(-(X_cdf-alpha)/beta)); %For fitted distribution
ks_cdf=exp(-exp(-(dataset-alpha)/beta)); %For fitted distribution

% Plot empirical and fitted CDF:
figure(2)
fitted=plot(X_cdf,Y_cdf,'-','color',0.3*[1 1 1]); %Plot fitted CDF
hold on
empirical=stairs(dataset,p_i,'-k'); %Plot empirical CDF

%Finding the measure "D":
ks=abs(ks_cdf-p_i);
D=max(ks);

i=1;
while D>ks(i)
    i=i+1;
end
% Plot "D":
D_plot=plot([dataset(i),dataset(i)],[ks_cdf(i),p_i(i)],'-r','LineWidth',3);

title('Kolmogorov-Smirnov test')
xlabel('$y_{max,1min}$','Interpreter','latex')
ylabel('Cumulative Probability')
legend([empirical,fitted,D_plot],{'Empirical CDF','Fitted CDF','D'});

% Identify extreme loads and other characteristics:
N=length(dataset);
n_hour=60*N/((stop-start)*0.5)
max_data=max(dataset)+25; %Largest measured load in the data set
x_max=alpha - beta*log(-log(1-1/N))+25; %Estimated largest for the data set

% End asymptotic.m --------------------------------------------------------