% Start bootstrapping.m ---------------------------------------------------

clear all
tic %This script may run for a while!
prompt = 'User input: Enter "1" for parameters estimated from',...
    'probability paper, "2" for maximum likelihood estimate (MLE)  ';
method = input(prompt);

% Number of bootstrapped samples:
n_boot=10000;

% Estimate distribution parameters for set defined in prob_paper.m:
run('parameters')

% Matrix for estimated parameters for each bootstrapped sample:
param=zeros(n_boot,2);

% Estimates of parameters from original dataset:
lambda_hat=lambda; %Exponential
sigma_hat=sigma; %Log-normal
mu_hat=mu; %Log-normal
beta_hat=beta; %Gumbel
alpha_hat=alpha; %Gumbel
k_hat=k; %Weibull
theta_hat=theta; %Weibull

% For plotting later: original (measured) dataset stored:
dataset_orig=dataset;

% Bootstrapping:
for i=1:n_boot
% Generate N (sample size) random numbers between 0 and 1 (cum. prob):
u=rand(N,1);

% Generate bootstrapped datasets from distribution with parameters
% calculated from the original data set:
if distr==1 %Exponential:
    dataset=-(log(1-u))/lambda_hat;
elseif distr==2 %Log-normal:
    dataset=exp(sigma_hat*norminv(u) + mu_hat);
elseif distr==3 %Gumbel:
    dataset=alpha_hat - beta_hat*log(-log(u));
elseif distr==4 %Weibull:
    dataset=theta_hat*(-log(1-u)).^(1/k_hat);
end

% Bottstrapped sample (dataset):
dataset=sort(dataset);

% Abscissa and ordinate transformations:
if distr==1 %Exponential:
    x=dataset;
    y=-log(1-p_i);
elseif distr==2 %Log-normal:
    x=log(dataset);
    y=norminv(p_i); %Normal inverse cumulative distribution function
elseif distr==3 %Gumbel:
    x=dataset;
    y=-log(-log(p_i));
elseif distr==4 %Weibull:
    x=log(dataset);
    y=log(-log(1-p_i));
end

% Plot (all) bootstrapped points in same figure:
hold on
scatter(x,y,'y*')

%Calculate new parameters based on the bootstrapped data.
bootstr=1; %Variable used to maintain the present dataset as "dataset" in 
no_plot=1; %Used for avoiding new plots of dataset in prob_paper.m
%figure(2)

if method==1 % Parameter estimation based on probability paper:
    if distr==1 %Exponential distribution
        c=0; %The exponential distribution is by def. starting at origo
        m=x\y.'; %solve for slope, intercept=0
    else
        m_c = polyfit(x,y',1);
        m=m_c(1); %slope
        c=m_c(2); %ordinate interception
    end
end

% Estimate distribution parameters for bootstrapped samples
run('parameters');
param(i,1)=parameter1;
param(i,2)=parameter2;
end %bootstrapping process

% Plot the orsginal data set in the same figure as the bootstrapped ones:
if distr==1
    %************EXPONENTIAL************
    x=dataset_orig;
    y=-log(1-p_i);
    
elseif distr==2
    %************LOGNORMAL************
    x=log(dataset_orig);
    y=norminv(p_i); %Normal inverse cumulative distribution function

elseif distr==3
    %*************GUMBEL**************
    x=dataset_orig;
    y=-log(-log(p_i));

elseif distr==4
    %*************WEIBULL*************
    x=log(dataset_orig);
    y=log(-log(1-p_i));
end
hold on
scatter(x,y,'bx')

toc
% End bootstrapping.m -----------------------------------------------------