% Start kolmogorov_smirnov.m ----------------------------------------------

prompt = 'User input: Enter "1" for parameters estimated from',...
    'probability paper, "2" for maximum likelihood estimate (MLE)  ';
method = input(prompt);

% Estimate distribution parameters for set defined in prob_paper.m:
run('parameters')
close

% Calculating points in CDF for fitted distribution:
X_cdf=0:1:max(dataset)*1.1;
if distr==1 % Exponential
    Y_cdf=expcdf(X_cdf,1/lambda);
    ks_cdf=expcdf(dataset,1/lambda);
elseif distr==2 %Log-normal
    Y_cdf=logncdf(X_cdf,mu,sigma);
    ks_cdf=logncdf(dataset,mu,sigma);
elseif distr==3 %Gumbel
    Y_cdf=exp(-exp(-(X_cdf-alpha)/beta));
    ks_cdf=exp(-exp(-(dataset-alpha)/beta));
elseif distr==4 %Weibull
    Y_cdf=wblcdf(X_cdf,theta,k);
    ks_cdf=wblcdf(dataset,theta,k);
elseif distr==5
    Y_cdf=a*(1-exp(-lambda1*X_cdf))+(1-a)*(1-exp(-lambda2*X_cdf));
    ks_cdf=a*(1-exp(-lambda1*dataset))+(1-a)*(1-exp(-lambda2*dataset));
end

% Plot empirical and fitted CDF:
empirical=stairs(dataset,p_i,'-k');
hold on
fitted=plot(X_cdf,Y_cdf,'color',0.3*[1 1 1]);
    
ks=abs(ks_cdf-p_i');

% Finding the measure "D":
D=max(ks);
% Calculate critical value of "D":
D_crit=1.36/sqrt(length(dataset)); %For alpha=0.05, n>50

if D>D_crit
    disp('KS-test: Rejected')
else
    disp('KS-test: Not rejected')
end

i=1;
while D>ks(i)
    i=i+1;
end

% Plot "D" and add labels, titles, legend, textbox
D_plot=plot([dataset(i),dataset(i)],[ks_cdf(i),p_i(i)],'r-','LineWidth',3);
title('Kolmogorov-Smirnov test')
xlabel('y')
ylabel('Cumulative Probability')
legend([empirical,fitted,D_plot],{'Empirical CDF','Fitted CDF','D'});
annotation('textbox',[0.7 0.65 0.15 0.11],'String',...
    {['D = ',num2str(D,'%.3f')],['D_{crit} = ',num2str(D_crit,'%.3f')]},...
    'FontSize',11,'FitBoxToText','off','EdgeColor','none');

% End kolmogorov_smirnov.m ------------------------------------------------