% Start prob_paper.m ------------------------------------------------------

if exist('bootstr', 'var')==0 %True if script is not ran by bootstrapping.m
close
clearvars -except method start stop LX
load('ILMdata') %Ice load monitoring data
run('separate');

% User inputs:
start=; %Start row in the matrix "data"/"time"
stop=; %End row in the matrix "data"/"time"
LX=; %Load (strain) sensor

prompt = 'Input: 1 for exponential distribution, 2 for Log-normal,',...
    '3 for Gumbel, 4 for Weibull, 5 for 3-parameter-exponential  ';
distr = input(prompt);

% Threshold:
threshold=25; %[kN] >= 25. 25 is default in the data set
if threshold>25
a=1;
LX_copy=LX;
clearvars LX
for i=1:length(LX_copy)
    if LX_copy(i,2)>threshold
        LX(a,:)=LX_copy(i,:);
        a=a+1;
    end
end
end

i=1;
% Find start point "i" for time series in "time":
while LX(i,1)<time(start)
    i=i+1;
end
j=i;
l_LX=length(LX);
% Finds end point "j" for time series in "time":
while LX(j,1)<time(stop) && j<l_LX
    j=j+1;
end

dataset=LX(i:j,2);
end %If the script is not ran by bootstrapping.m
dataset=sort(dataset);

N=length(dataset);
% Empirical CDF:
p_i=1:N;
p_i=p_i/(N+1);

if exist('bootstr','var')==0 %True if script is not ran by bootstrapping.m
dataset=dataset-threshold; %For fitting in probability papers
end

if distr==1 %Exponential
    %Abscissa and ordinate transformations (x and y):
    x=dataset;
    y=-log(1-p_i);
    hold on
    xlabel('y')
    ylabel('Cumulative Probability')
    title('Exponential distribution')
    scatter(x,y,'x')
    
elseif distr==2 %Log-normal
    hold on
    xlabel('y')
    ylabel('Cumulative Probability')
    title('Log-normal distribution')
    x=log(dataset);
    y=norminv(p_i); %Normal inverse cumulative distribution function
    scatter(x,y,'x')

elseif distr==3 %Gumbel
    x=dataset;
    y=-log(-log(p_i));
    hold on
    xlabel('y')
    ylabel('Cumulative Probability')
    title('Gumbel distribution')
    scatter(x,y,'x')
    hold off

elseif distr==4 %Weibull
    x=log(dataset);
    y=log(-log(1-p_i));

    hold on
    xlabel('y')
    ylabel('Cumulative Probability')
    title('Weibull distribution')
    scatter(x,y,'x')
    
elseif distr==5 %Three-parameter exponential
    run('three_param_exp');
    return
end

% Fitted distribution:
if distr==1 %Exponential
    c=0; %The exponential distribution is by def. starting at the origo
    m=x\y.'; %solve for slope, zero intercept
    yhat=[0 y(end)]; %evaluate over same range from origin
    plot([0 y(end)/m],yhat,'k-') %plot fitted line
elseif distr==2 %Log-normal. Fitted line based on MLE parameters
    mu=sum(log(dataset))/N;
    sigma=sqrt(sum((log(dataset)-mu).^2)/N);
    xx=[logninv(1/length(x),mu,sigma) , logninv((length(x)+1)/(length(x)...
        +2),mu,sigma)];
    xx=log(xx);
    yy=[norminv(1/length(x)) , norminv((length(x)+1)/(length(x)+2))];
    scatter(xx,yy,'.w')%create two points based on the MLE parameters to...
    %create the fitted line
    l=lsline; %plot least square fitted line
    set(l(1),'color',0.0*[1 1 1]) %Color of the fitted line
    m_c = polyfit(xx,yy,1);
    m=m_c(1); %slope
    c=m_c(2); %ordinate interception
elseif distr==3 %Gumbel
    l=lsline; %plot the fitted line
    set(l(1),'color',0.0*[1 1 1]) %Color of the fitted line
    m_c = polyfit(get(l,'xdata'),get(l,'ydata'),1);
    m=m_c(1); %slope
    c=m_c(2); %ordinate interception
elseif distr==4 %Weibull. Fitted line based on MLE parameters
    thetak=wblfit(dataset); %Parameter estimation for Weibull using MLE
    k=thetak(2); %Weibull
    theta=((1/N)*sum(dataset.^k))^(1/k); %Weibull
    xx=[wblinv(1/length(x),theta,k) ,...
        wblinv((length(x)+1)/(length(x)+2),theta,k)];
    xx=log(xx);
    yy=[log(-log(1-(1/length(x)))) ,...
        log(-log(1-((length(x)+1)/(length(x)+2))))];
    scatter(xx,yy,'.w')%create two points based on the MLE parameters...
    %to create the fitted line
    l=lsline; %plot the fitted line
    set(l(1),'color',0.0*[1 1 1]) %Color of the fitted line
    m_c = polyfit(xx,yy,1);
    m=m_c(1); %slope
    c=m_c(2); %ordinate interception
end

if exist('bootstr','var')==0 %True if script is not ran by bootstrapping.m
% Coefficient of Determination (R^2):
f=m*x+c;
y_bar=mean(y);
SSres=sum((y-f.').^2);
SStot=sum((y-y_bar).^2);
R_squared=1-(SSres/SStot);
end

% End prob_paper.m --------------------------------------------------------