% Start qq_plot.m ---------------------------------------------------------

clear all
load('ILMdata') %Ice load monitoring data
run('separate');

start=;
stop=;
LX=;

% Threshold:
threshold=25; %[kN] >= 25. 25 is default in the data set
if threshold>25
a=1;
LX_copy=LX;
clearvars LX
for i=1:length(LX_copy)
    if LX_copy(i,2)>threshold
        LX(a,:)=LX_copy(i,:);
        a=a+1;
    end
end
end

i=1;
% Find start point "i" for time series in "time":
while LX(i,1)<time(start)
    i=i+1;
end
j=i;
l_LX=length(LX);
% Finds end point "j" for time series in "time":
while LX(j,1)<time(stop) && j<l_LX
    j=j+1;
end

dataset=LX(i:j,2);
dataset=sort(dataset);
% Empirical CDF:
p_i=1:length(dataset);
p_i=p_i/(length(dataset)+1);

prompt = 'User input: 1 for parameters estimated from probability',...
    'paper, 2 for maximum likelihood estimate (MLE)  ';
method = input(prompt);

% Estimate distribution parameters:
run('parameters')
close all

% Calculate load value for each quantile for fitted distribution
if distr==1 %Exponential
    X=-log(1-p_i)/lambda;
elseif distr==2 %Log-normal
    X=exp(sigma*norminv(p_i) + mu);
elseif distr==3 %Gumbel
    X=alpha - beta*log(-log(p_i));
elseif distr==4 %Weibull
    X=theta*(-log(1-p_i)).^(1/k);
end

% Q-Q plot:
scatter(X,dataset)
hold on
% Plot line with slope 1 through origin (line of perfect match):
plot([0,max(max(dataset,X))],[0,max(max(dataset,X))])
xlabel({'$\hat{y}$'},'Interpreter','latex')
ylabel('y')
if distr==1
    title('Q-Q plot Exponential distribution')
elseif distr==2
    title('Q-Q plot Log-normal distribution')
elseif distr==3
    title('Q-Q plot Gumbel distribution')
elseif distr==4
    title('Q-Q plot Weibull distribution')
end
hold off

% End qq_plot.m -----------------------------------------------------------